varying vec2 v_texCoord;
varying vec4 v_fragmentColor;

uniform sampler2D _BloomSampler;
uniform float _BloomIntensity;
uniform float _BloomSaturation;
uniform float _BaseIntensity;
uniform float _BaseSaturation;
uniform float _LightIntensity;

void main()
{
	vec3 coeff = vec3(0.300000012, 0.589999974, 0.109999999);
				
	vec4 baseColor = texture2D(CC_Texture0,v_texCoord);
	vec4 bloomColor = texture2D(_BloomSampler,vec2(v_texCoord.x,1.0 - v_texCoord.y));

	float v = dot(coeff,baseColor.xyz);
	vec4 lumin = vec4(v,v,v,v);
	vec4 color1 = mix(lumin,baseColor,_BaseSaturation);
	color1.a = baseColor.a;
	color1 = color1 * _BaseIntensity;

	v = dot(coeff,bloomColor.xyz);
	lumin = vec4(v,v,v,v);
	vec4 color2 = mix(lumin,bloomColor,_BloomSaturation);
	color2.a = bloomColor.a;
	color2 = color2 * _BloomIntensity;

	vec4 diffuse = 1.0 - clamp(color2,0.0,1.0);
	vec4 color = color1 * diffuse + color2;
	float t = v_texCoord.x * v_texCoord.y * _LightIntensity;

	color.r = mix(color.r,v_fragmentColor.r,t);
	color.g = mix(color.g,v_fragmentColor.g,t);
	color.b = mix(color.b,v_fragmentColor.b,t);
	color.a = baseColor.a;

	gl_FragColor = color;
}